@@ -37,29 +37,29 @@
 --  >     size stated in the header, to accept output of foolish Win7 codec.
 --
 module Codec.BMP
-	( -- * Data Structures
-          BMP		  (..)
-	, FileHeader  	  (..)
-	, BitmapInfo      (..)
-	, BitmapInfoV3	  (..)
-	, BitmapInfoV4    (..)
-	, BitmapInfoV5    (..)
-	, Compression     (..)
-	, CIEXYZ          (..)
-	, Error           (..)
+        ( -- * Data Structures
+          BMP             (..)
+        , FileHeader      (..)
+        , BitmapInfo      (..)
+        , BitmapInfoV3    (..)
+        , BitmapInfoV4    (..)
+        , BitmapInfoV5    (..)
+        , Compression     (..)
+        , CIEXYZ          (..)
+        , Error           (..)
 
           -- * Reading
-	, readBMP,  hGetBMP, parseBMP
+        , readBMP,  hGetBMP, parseBMP
 
           -- * Writing
-	, writeBMP, hPutBMP, renderBMP
+        , writeBMP, hPutBMP, renderBMP
 
           -- * Pack and Unpack
-	, packRGBA32ToBMP
+        , packRGBA32ToBMP
         , packRGBA32ToBMP32
         , packRGBA32ToBMP24
-	, unpackBMPToRGBA32
-	, bmpDimensions)
+        , unpackBMPToRGBA32
+        , bmpDimensions)
 where
 import Codec.BMP.Base
 import Codec.BMP.Error
@@ -71,8 +71,7 @@ import Codec.BMP.BitmapInfoV3
 import Codec.BMP.BitmapInfoV4
 import Codec.BMP.BitmapInfoV5
 import System.IO
-import Data.ByteString		as BS
-import Data.ByteString.Lazy	as BSL
+import Data.ByteString.Lazy     as BSL
 import Data.Binary
 import Data.Binary.Get
 
@@ -82,14 +81,14 @@ import Data.Binary.Get
 --      If there is anything wrong this gives an `Error` instead.
 readBMP :: FilePath -> IO (Either Error BMP)
 readBMP fileName
- = do	h	<- openBinaryFile fileName ReadMode
-	hGetBMP h
-	
+ = do   h       <- openBinaryFile fileName ReadMode
+        hGetBMP h
+        
 -- | Get a BMP image from a file handle.
 hGetBMP :: Handle -> IO (Either Error BMP)
 hGetBMP h
- = do	-- lazily load the whole file
-	buf	<- BSL.hGetContents h
+ = do   -- lazily load the whole file
+        buf     <- BSL.hGetContents h
         return $ parseBMP buf
 
 
@@ -97,26 +96,26 @@ hGetBMP h
 parseBMP :: BSL.ByteString -> Either Error BMP
 parseBMP buf
  = let  -- split off the file header
-	(bufFileHeader, bufRest) 
-	       = BSL.splitAt (fromIntegral sizeOfFileHeader) buf
+        (bufFileHeader, bufRest) 
+               = BSL.splitAt (fromIntegral sizeOfFileHeader) buf
 
    in   if (fromIntegral $ BSL.length bufFileHeader) /= sizeOfFileHeader
-	 then	Left ErrorFileHeaderTruncated
-	 else	parseBMP2 bufRest (decode bufFileHeader)
-	
+         then   Left ErrorFileHeaderTruncated
+         else   parseBMP2 bufRest (decode bufFileHeader)
+        
 parseBMP2 buf fileHeader
  -- Check the magic before doing anything else.
  | fileHeaderType fileHeader /= bmpMagic
  = Left $ ErrorBadMagic (fileHeaderType fileHeader)
-	
+        
  | otherwise
- = let	-- Next comes the image header. 
-	-- The first word tells us how long it is.
-	sizeHeader	= runGet getWord32le buf
-	
-	-- split off the image header
-	(bufImageHeader, bufRest)
-		= BSL.splitAt (fromIntegral sizeHeader) buf
+ = let  -- Next comes the image header. 
+        -- The first word tells us how long it is.
+        sizeHeader      = runGet getWord32le buf
+        
+        -- split off the image header
+        (bufImageHeader, bufRest)
+                = BSL.splitAt (fromIntegral sizeHeader) buf
         
         -- How much non-header data is present in the file.
         -- For uncompressed data without a colour table, the remaining data
@@ -126,67 +125,67 @@ parseBMP2 buf fileHeader
                 = (fromIntegral $ BSL.length bufRest) :: Word32
 
    in if (fromIntegral $ BSL.length bufImageHeader) /= sizeHeader
-	 then 	Left ErrorImageHeaderTruncated
-	 else 	parseBMP3 fileHeader bufImageHeader bufRest physicalBufferSize
+         then   Left ErrorImageHeaderTruncated
+         else   parseBMP3 fileHeader bufImageHeader bufRest physicalBufferSize
 
 
 parseBMP3 fileHeader bufImageHeader bufRest physicalBufferSize
-	| BSL.length bufImageHeader == 40 
-	= let info	= decode bufImageHeader
-	  in  case checkBitmapInfoV3 info physicalBufferSize of
-		 Just err	-> Left err
-		 Nothing
+        | BSL.length bufImageHeader == 40 
+        = let info      = decode bufImageHeader
+          in  case checkBitmapInfoV3 info physicalBufferSize of
+                 Just err       -> Left err
+                 Nothing
                   |  Just imageSize      <- imageSizeFromBitmapInfoV3 info
                   -> parseBMP4 fileHeader (InfoV3 info) bufRest imageSize
 
                   |  otherwise
                   -> Left $ ErrorInternalErrorPleaseReport
 
-	| BSL.length bufImageHeader == 108
-	= let info	= decode bufImageHeader
-	  in  case checkBitmapInfoV4 info physicalBufferSize of
-		 Just err	-> Left err
-		 Nothing	
+        | BSL.length bufImageHeader == 108
+        = let info      = decode bufImageHeader
+          in  case checkBitmapInfoV4 info physicalBufferSize of
+                 Just err       -> Left err
+                 Nothing        
                   | Just imageSize      <- imageSizeFromBitmapInfoV4 info
                   -> parseBMP4 fileHeader (InfoV4 info) bufRest imageSize
 
                   | otherwise
                   -> Left $ ErrorInternalErrorPleaseReport
-		
-	| BSL.length bufImageHeader == 124
-	= let info	= decode bufImageHeader
-	  in  case checkBitmapInfoV5 info physicalBufferSize of
-		 Just err	-> Left err
-		 Nothing	
+                
+        | BSL.length bufImageHeader == 124
+        = let info      = decode bufImageHeader
+          in  case checkBitmapInfoV5 info physicalBufferSize of
+                 Just err       -> Left err
+                 Nothing        
                   | Just imageSize      <- imageSizeFromBitmapInfoV5 info
                   -> parseBMP4 fileHeader (InfoV5 info) bufRest imageSize
 
                   | otherwise
                   -> Left $ ErrorInternalErrorPleaseReport
-		
-	| otherwise
- 	= Left $ ErrorUnhandledBitmapHeaderSize 
+                
+        | otherwise
+        = Left $ ErrorUnhandledBitmapHeaderSize 
                $ fromIntegral $ BSL.length bufImageHeader
 
 
 parseBMP4 fileHeader imageHeader bufImage (sizeImage :: Int)
  = let  bufLen  = fromIntegral $ BSL.length bufImage
    in   if bufLen < sizeImage
-	 then Left $ ErrorImageDataTruncated sizeImage bufLen
-	 else Right $ BMP 
-		{ bmpFileHeader 	= fileHeader
-		, bmpBitmapInfo		= imageHeader
-		, bmpRawImageData	= BS.concat $ BSL.toChunks bufImage }
+         then Left $ ErrorImageDataTruncated sizeImage bufLen
+         else Right $ BMP 
+                { bmpFileHeader         = fileHeader
+                , bmpBitmapInfo         = imageHeader
+                , bmpRawImageData       = BSL.toStrict bufImage }
 
 
 -- Writing --------------------------------------------------------------------
 -- | Wrapper for `hPutBMP`
 writeBMP :: FilePath -> BMP -> IO ()
 writeBMP fileName bmp
- = do	h	<- openBinaryFile fileName WriteMode
-	hPutBMP h bmp
-	hFlush h
-	hClose h
+ = do   h       <- openBinaryFile fileName WriteMode
+        hPutBMP h bmp
+        hFlush h
+        hClose h
 
 
 -- | Put a BMP image to a file handle.
@@ -204,11 +203,11 @@ renderBMP bmp
 
 
 -- | Get the width and height of an image.
---	It's better to use this function than to access the headers directly.
+--      It's better to use this function than to access the headers directly.
 bmpDimensions :: BMP -> (Int, Int)
-bmpDimensions bmp	
- = let	info	= getBitmapInfoV3 $ bmpBitmapInfo bmp
-   in	( fromIntegral $ dib3Width info
-	, fromIntegral $ dib3Height info)
+bmpDimensions bmp       
+ = let  info    = getBitmapInfoV3 $ bmpBitmapInfo bmp
+   in   ( fromIntegral $ dib3Width info
+        , fromIntegral $ dib3Height info)
 
 
